@@ -2,6 +2,12 @@
 #include <TelepathyQt4/PendingChannelRequest>
 #include <TelepathyQt4/Connection>
 
+#if defined(Q_WS_MAEMO_5)
+#define CSD_SERVICE         "com.nokia.csd"
+#define CSD_CALL_PATH		"/com/nokia/csd/call"
+#define CSD_CALL_INTERFACE	"com.nokia.csd.Call"
+#endif
+
 TpCalloutInitiator::TpCalloutInitiator (Tp::AccountPtr act, QObject *parent)
 : CalloutInitiator(parent)
 , account (act)
@@ -115,8 +121,11 @@ TpCalloutInitiator::onConnectionReady (Tp::PendingOperation *op)
 }//TpCalloutInitiator::onConnectionReady
 
 void
-TpCalloutInitiator::initiateCall (const QString &strDestination)
+TpCalloutInitiator::initiateCall (const QString &strDestination,
+                                  void *ctx /*= NULL*/)
 {
+    m_Context = ctx;
+
     QVariantMap request;
     request.insert(TELEPATHY_INTERFACE_CHANNEL ".ChannelType",
                    TELEPATHY_INTERFACE_CHANNEL_TYPE_STREAMED_MEDIA);
@@ -140,6 +149,7 @@ TpCalloutInitiator::initiateCall (const QString &strDestination)
 void
 TpCalloutInitiator::onChannelReady (Tp::PendingOperation*op)
 {
+    bool bSuccess = false;
     do { // Begin cleanup block (not a loop)
         if (op->isError ()) {
             qWarning ("Channel could not become ready");
@@ -147,9 +157,12 @@ TpCalloutInitiator::onChannelReady (Tp::PendingOperation*op)
         }
 
         qDebug ("Call successful");
+        bSuccess = true;
     } while (0); // End cleanup block (not a loop)
 
-     op->deleteLater ();
+    emit callInitiated (bSuccess, m_Context);
+
+    op->deleteLater ();
 }//TpCalloutInitiator::onChannelReady
 
 QString
@@ -170,3 +183,30 @@ TpCalloutInitiator::isValid ()
     return (!account.isNull () && !account->connection().isNull () &&
             account->isEnabled () && account->isValid ());
 }//TpCalloutInitiator::isValid
+
+bool
+TpCalloutInitiator::sendDTMF (const QString &strTones)
+{
+#if defined(Q_WS_MAEMO_5)
+    if ("ring" == account->cmName ()) {
+        QList<QVariant> argsToSend;
+        argsToSend.append(strTones);
+        argsToSend.append(0);
+        QDBusConnection systemBus = QDBusConnection::systemBus();
+        QDBusMessage dbusMethodCall =
+        QDBusMessage::createMethodCall(CSD_SERVICE,
+                                       CSD_CALL_PATH,
+                                       CSD_CALL_INTERFACE,
+                                       QString("SendDTMF"));
+        dbusMethodCall.setArguments(argsToSend);
+        bool rv = systemBus.send(dbusMethodCall);
+        if (!rv) {
+            qDebug ("Dbus method call to send DTMF failed.");
+        }
+        return rv;
+    }
+#endif
+
+    //@@UV: Add DTMF to Telepathy
+    return false;
+}//TpCalloutInitiator::sendDTMF
